pub type CollectionInfoOf<T> = CollectionInfo<<T as Config>::AccountId, BalanceOf<T>, <T as Config>::Consideration>;Aliased Type
pub struct CollectionInfoOf<T> {
pub owner: <T as Config>::AccountId,
pub pending_owner: Option<<T as Config>::AccountId>,
pub next_item_index: u32,
pub item_count: u32,
pub metadata_count: u32,
pub collection_deposit: <T as Config>::Balance,
pub owner_deposit: <T as Config>::Balance,
pub consideration: <T as Config>::Consideration,
}Fields
owner: <T as Config>::AccountIdOnly this account may perform collection-owner-authorized operations.
pending_owner: Option<<T as Config>::AccountId>Account nominated by owner to claim the collection.
next_item_index: u32The next item index to allocate, beginning at zero.
item_count: u32Number of item definitions which have not been deleted.
metadata_count: u32Number of collection-level metadata entries.
collection_deposit: <T as Config>::BalanceExact deposit for the collection record itself.
owner_deposit: <T as Config>::BalanceExact aggregate deposit represented by consideration.
consideration: <T as Config>::ConsiderationOpaque consideration ticket backing owner_deposit on behalf of owner.