referrerpolicy=no-referrer-when-downgrade

CollectionMetadata

Type Alias CollectionMetadata 

pub type CollectionMetadata<T: Config> = StorageDoubleMap<_GeneratedPrefixForStorageCollectionMetadata<T>, Twox64Concat, CollectionId, Blake2_128Concat, MetadataKeyOf<T>, MetadataEntry<MetadataValueOf<T>, BalanceOf<T>>>;
Collection-wide defaults inherited by every item in a collection.

Entries must be removed individually before the collection can be deleted.

Storage type is [StorageDoubleMap] with key1 type CollectionId, key2 type MetadataKeyOf < T > and value type MetadataEntry < MetadataValueOf < T > , BalanceOf < T > >.

Aliased Type

pub struct CollectionMetadata<T: Config>(/* private fields */);